@@ -16,7 +16,7 @@ from climetlab.indexing import PerUrlIndex
 from ..config import baseurl
 from ..utils import convert_to_datetime
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 _terms_of_use = """By downloading data from this dataset, you agree to the terms and conditions defined at
 
@@ -297,7 +297,7 @@ class TrainingDataForecastPressure(TrainingDataForecast):
             self.source = cml.load_source("indexed-urls", PerUrlIndex(self._PATTERN), request)
 
 
-class TrainingDataForecastSurfacePostProcessed(TrainingDataForecast):
+class TrainingDataForecastSurfaceProcessed(TrainingDataForecast):
     name = None  # TODO
     home_page = "-"  # TODO
     licence = "-"  # TODO
